@@ -18,6 +18,8 @@ extern conninit *cntrl;
 extern int cntrl_num;
 extern int skip_ok, probe_all;
 extern int skip_verification;
+extern int need_desthdr;
+extern int sp_port, sp_spec;
 extern fd_set rdset, wrset;
 extern struct sockaddr *proxyhost;
 extern socklen_t proxyhostlen;
