@@ -2,7 +2,7 @@
 #define CONTROL_H
 
 void add_proxy(char *proxy, int port, int probe);
-void proxy_final(void);
+void proxy_final(int dest_included);
 int resolve_proxy(char *proxy, char *dest);
 
 #endif
