@@ -13,6 +13,9 @@ int probe_all = 0;			/* Do an UDP probe on all proxies		*/
 int skip_ok = 0;			/* May skip proxies in a chain if they are not up	*/
 int skip_verification = 0;		/* Set true if the Server signature does nto have to be verified	*/
 int h_errno;				/* Resolver error var.				*/
+int need_desthdr = 0;			/* Do we need to read in destination host header?	*/
+int sp_port = 0;			/* Specified source port			*/
+int sp_spec = 0;			/* Sourceport specification? 0=no, 1=adv, 2=man	*/
 struct sockaddr *proxyhost = NULL;	/* First proxy, used for a direct connection.	*/
 socklen_t proxyhostlen = 0;		/* Size of proxyhost				*/
 #ifdef IPV6				/* Runtime ipv6 support checking		*/
