@@ -10,7 +10,7 @@ int StorePublicKey(char *file, R_RSA_PUBLIC_KEY *publicKey);
 int LoadPublicKey(char *file, R_RSA_PUBLIC_KEY *publicKey);
 int StorePrivateKey(char *file, R_RSA_PRIVATE_KEY *privateKey);
 int LoadPrivateKey(char *file, R_RSA_PRIVATE_KEY *privateKey);
-int StorePart(FILE *fptr, char *src, int size);
-int LoadPart(FILE *fptr, char *dest, int size);
+int StorePart(FILE *fptr, void *src, int size);
+int LoadPart(FILE *fptr, void *dest, int size);
 
 #endif
