@@ -3,6 +3,7 @@
 
 #include "sysdeps.h"
 #include "aesop.h"
+#include "defaults.h"
 
 #ifndef have_socklen_t
  typedef int socklen_t;
@@ -20,6 +21,7 @@
 #include <stdarg.h>
 #include <time.h>
 #include <syslog.h>
+#include <signal.h>
 #include <sys/param.h>
 #include <sys/time.h>
 #include <sys/types.h>
@@ -46,14 +48,7 @@
 
 #include "compat.h"
 
-#define VERSION                 "0.3"
-#define LISTEN_PORT             6789    /* Default listen port  */
-#define LISTEN_PORT_STRING      "6789"  /* Default listen port as string */
-#define DEFAULT_PORT		LISTEN_PORT
-#define MAX_SIMUL_CONNECT       30      /* Default upper limit on simultaneous connections      */
-#define TIMEOUT                 10      /* 10 seconds time out for client to send conninit structure */
-#define PRIVATE_KEY_FILE        "Server.prv"
-#define PUBLIC_KEY_FILE         "Server.pub"
+#define VERSION                 "0.4"
 
 #ifndef MAX
  #define MAX(x, y)       ((x) > (y) ? (x) : (y))
@@ -69,5 +64,6 @@
 extern int h_errno;
 extern int debug;
 extern int daemon_proc;
+extern char *seedfile;
 
 #endif
